@@ -1,3 +1,6 @@
+"""
+loggin utilities
+"""
 from contextlib import contextmanager
 import logging
 import time
@@ -22,61 +25,60 @@ def progressbar(iterable, log=None):
 
     """
     if log is None:
-        log = logging.getLogger()
+        log = logging
     try:
-        from tqdm import tqdm as progressor
+        # tqdm not required for the module to work
+        from tqdm import tqdm as progressor  # pylint: disable=import-outside-toplevel
 
         tqdm_exists = True
     except ImportError:
 
         def progressor(iterable):
             """
-            dummy function. Doe nothing
+            dummy function. Does nothing
             """
             return iterable
 
         tqdm_exists = False
     try:
-        nTotal = len(iterable)
-    except Exception:
-        nTotal = None
+        n_total = len(iterable)
+    except TypeError:
+        n_total = None
 
     for i in progressor(iterable):
         if not tqdm_exists:
-            if nTotal is None:
+            if n_total is None:
                 log.info("Progress: item {i}".format(**locals()))
             else:
-                log.info("Progress: {i} / {nTotal}".format(**locals()))
+                log.info("Progress: {i} / {n_total}".format(**locals()))
         yield i
 
 
 @contextmanager
-def timeit(msg="No Description", log=None, precision=1) -> None:
+def timeit(process_name="No Description", log=None, precision=1) -> None:
     """
     Context manager for autmated timeing
 
     Args:
-        msg (str): message to customize the log message
+        process_name (str): message to customize the log message
         log (logger)
         precision (int): show until 10^-<precision> digits
     """
     if log is None:
-        log = logging.getLogger()
-    startTime = time.time()
-    log.log(logging.INFO, "-> " * 30)
-    message = "Starting Process: {0} ->".format(msg)
+        log = logging
+    start_time = time.time()
+    message = "Timing Process: {0} ...".format(process_name)
     log.log(logging.INFO, message)
 
     yield
 
     log.log(
         logging.INFO,
-        "\t\t\t\t\t\t<- Process Duration:"
+        "\t\t\t\t\t\t... Process Duration:"
         "{value:1.{precision}f} s".format(
-            value=time.time() - startTime, precision=precision
+            value=time.time() - start_time, precision=precision
         ),
     )
-    log.log(logging.INFO, "<- " * 30)
 
 
 if __name__ == "__main__":
