@@ -17,7 +17,11 @@ except (ImportError, AttributeError):
 import glob
 
 
-class Path(type(PathlibPath())):
+class Path(type(PathlibPath())):  # pylint: disable=too-few-public-methods
+    """
+    pathlib inherited Path, improved by some methods
+    """
+
     def resolve(self):
         """
         TODO: look at this https://bugs.python.org/issue19776
@@ -64,7 +68,7 @@ def resolve(path, *joins):
     return path
 
 
-def cp(source, dest, overwrite=True):
+def cp(source, dest, overwrite=True):  # pylint: disable=invalid-name
     """
     copy with shutil
     """
@@ -92,19 +96,18 @@ def scp(source, dest):
     subprocess.check_call(["scp", source, dest])
 
 
-def mv(source, dest, overwrite=True):
+def mv(source, dest, overwrite=True):  # pylint: disable=invalid-name
     """
     Move files or whole folders
     """
     source = resolve(source)
     dest = resolve(dest)
-    log = logging.getLogger()
     if os.path.isfile(dest) and not overwrite:
         raise ValueError(
             "Attempting to move to already existing destination"
             " path {0}.".format(dest)
         )
-    log.info("Moving file or dir {0} to {1}".format(source, dest))
+    logging.info("Moving file or dir %s to %s", source, dest)
     if os.path.isfile(source):
         shutil.move(source, dest)
     elif os.path.isdir(source):
@@ -114,7 +117,7 @@ def mv(source, dest, overwrite=True):
         raise TypeError("source is not file or dir")
 
 
-def rm(path):
+def rm(path):  # pylint: disable=invalid-name
     """
     Remove path or (empty) directory
     """
@@ -129,7 +132,7 @@ def rm(path):
         raise ValueError("Path {0} is not directory and not file".format(path))
 
 
-def cd(directory):
+def cd(directory):  # pylint: disable=invalid-name
     """
     Change directory
     """
@@ -137,19 +140,19 @@ def cd(directory):
 
 
 @contextlib.contextmanager
-def cd_tmp(tmpPath):
+def cd_tmp(tmp_path):
     """
     Temporarily change directory. change back afterwards
     """
     cwd = os.getcwd()
-    cd(resolve(tmpPath))
+    cd(resolve(tmp_path))
     try:
         yield
     finally:
         cd(cwd)
 
 
-def ls(directory, **kwargs):
+def ls(directory, **kwargs):  # pylint: disable=invalid-name
     """
     a bash ls imitation.
     allows wildcards
@@ -160,28 +163,30 @@ def ls(directory, **kwargs):
     return [os.path.basename(p) for p in glob.iglob(directory, **kwargs)]
 
 
-def mkdir(path, isDir=False):
+def mkdir(path, is_dir=False):
     """
+    Like mkdir -p
+
     Notes:
-        if you want to create a dir, add '/' behind path or use isDir=True
+        if you want to create a dir, add '/' behind path or use is_dir=True
+
     Args:
         path (str): directory or path to create.
-        isDir (str): tell mkdir that you are explicitly giving a directory.
+        is_dir (str): tell mkdir that you are explicitly giving a directory.
     """
-    log = logging.getLogger()
     path = resolve(path)
-    if isDir:
+    if is_dir:
         directory = path
     else:
         directory = os.path.dirname(path)
     if not os.path.exists(directory) and not directory == "":
-        log.info("Create directory {0}".format(directory))
+        logging.info("Create directory %s", directory)
         os.makedirs(directory)
     else:
-        log.warning("Directory {0} already exists".format(directory))
+        logging.warning("Directory %s already exists", directory)
 
 
-def dir_structure(directory):
+def tree(directory):
     """
     Creates a nested dictionary that represents the folder structure of
     directory
@@ -189,7 +194,7 @@ def dir_structure(directory):
     dir_structure = {}
     directory = directory.rstrip(os.sep)
     start = directory.rfind(os.sep) + 1
-    for path, dirs, files in os.walk(directory):
+    for path, dirs, files in os.walk(directory):  # pylint: disable=unused-variable
         folders = path[start:].split(os.sep)
         subdir = dict.fromkeys(files)
         parent = functools.reduce(dict.get, folders[:-1], dir_structure)
