@@ -1,8 +1,6 @@
 """
 Matplotlib specific plotting
 """
-import rna
-
 import numpy as np
 import re
 import warnings
@@ -21,6 +19,9 @@ from functools import partial
 import logging
 
 
+import rna
+
+
 def show():
     plt.show()
 
@@ -92,7 +93,7 @@ def upgrade_style(style, source, dest=None):
         >>> import rna
         >>> import os
         >>> rna.plotting.use('matplotlib')
-        >>> rna.plotting._backend_mod.upgrade_style(
+        >>> rna.plotting._BACKEND_MOD.upgrade_style(
         ...     'rna',
         ...     os.path.join(os.path.dirname(rna.plotting.__file__),
         ...                  'mplstyles/rna.mplstyle'))
@@ -382,15 +383,16 @@ def plot_mesh(vertices, faces, **kwargs):
         from rna.plotting.colors import color_fmt
 
         orig_fmt = color_fmt(color)
-        orig_color = color
+        if orig_fmt == "norm":
+            orig_color = po.format_colors(color, fmt="norm", length=len(faces))
 
-        nanMask = np.isnan(color)
-        if nanMask.any():
+        color = po.format_colors(color, fmt="rgba", length=len(faces), dtype=float)
+
+        nan_mask = np.isnan(color)
+        if nan_mask.any():
             warnings.warn("nan found in colors. Removing corresponding faces!")
-            color = color[~nanMask]
-            faces = faces[~nanMask]
-
-        color = po.format_colors(color, fmt="rgba", length=len(faces))
+            color = color[~nan_mask]
+            faces = faces[~nan_mask]
 
         edgecolor = po.pop("edgecolor", None)
         alpha = po.pop("alpha", None)
@@ -405,9 +407,9 @@ def plot_mesh(vertices, faces, **kwargs):
 
         if edgecolor is not None:
             artist.set_edgecolor(edgecolor)
-            artist.set_facecolors(color.tolist())
+            artist.set_facecolors(color)
         else:
-            artist.set_color(color.tolist())
+            artist.set_color(color)
         if orig_fmt == "norm":
             # sets vmin, vmax to min, max of val
             artist.set_array(np.array(orig_color))
@@ -583,7 +585,7 @@ def plot_function(fun, **kwargs):
     """
     import numpy as np
 
-    labels = ["x", "f(x)"]
+    labels = ["x", "f(x)"]  # TODO make kwarg
     po = rna.plotting.PlotManager(kwargs)
     rna.plotting.set_labels(po.axes, *labels)
     xMin, xMax = po.pop("xMin", 0), po.pop("xMax", 1)
@@ -1034,7 +1036,7 @@ class Writer(FFMPEGWRITER):
         >>> import numpy as np
         >>> import rna
         >>> axes = rna.plotting.gca()
-        >>> writer = rna.plotting._backend_mod.Writer()
+        >>> writer = rna.plotting._BACKEND_MOD.Writer()
         >>> pictures = np.array([[[1,1], [0,0]],
         ...                      [[0.5,1], [0,0.5]]])
         >>> with writer.saving():
