@@ -10,8 +10,8 @@ import matplotlib.pyplot as plt
 
 FMT_DTYPES = {
     # 'hex': np.dtype([('hex', '<U7')]),
-    'rgba': np.dtype([('r', '<f8'), ('g', '<f8'), ('b', '<f8'), ('a', '<f8')]),
-    'rgb': np.dtype([('r', '<f8'), ('g', '<f8'), ('b', '<f8')]),
+    "rgba": np.dtype([("r", "<f8"), ("g", "<f8"), ("b", "<f8"), ("a", "<f8")]),
+    "rgb": np.dtype([("r", "<f8"), ("g", "<f8"), ("b", "<f8")]),
 }
 
 
@@ -38,7 +38,9 @@ def color_fmt(colors):
             if dtype == colors.dtype:
                 return fmt
 
-    if not hasattr(colors, '__iter__') or isinstance(colors, (string_types, tuple)):  # NOQA
+    if not hasattr(colors, "__iter__") or isinstance(
+        colors, (string_types, tuple)
+    ):  # NOQA
         # colors is just one element
         colors = [colors]
     color = colors[0]
@@ -51,30 +53,32 @@ def color_fmt(colors):
             pass
         else:
             if isinstance(c, norm_types):
-                return 'gray'
-        if color.startswith('#'):
-            return 'hex'
-        return 'str'
+                return "gray"
+        if color.startswith("#"):
+            return "hex"
+        return "str"
     if isinstance(color, tuple):
-        if len(color) == len(FMT_DTYPES['rgba']):
-            return 'rgba'
-        if len(color) == len(FMT_DTYPES['rgb']):
-            return 'rgb'
+        if len(color) == len(FMT_DTYPES["rgba"]):
+            return "rgba"
+        if len(color) == len(FMT_DTYPES["rgb"]):
+            return "rgb"
     if isinstance(color, norm_types):
-        return 'norm'
+        return "norm"
     return None
 
 
 def truncate_colormap(cmap, vmin=0.0, vmax=1.0, n=100):
     cmap = plt.get_cmap(cmap)
     new_cmap = mpl.colors.LinearSegmentedColormap.from_list(
-        'trunc({n},{a:.2f},{b:.2f})'.format(n=cmap.name, a=vmin, b=vmax),
-        cmap(np.linspace(vmin, vmax, n)))
+        "trunc({n},{a:.2f},{b:.2f})".format(n=cmap.name, a=vmin, b=vmax),
+        cmap(np.linspace(vmin, vmax, n)),
+    )
     return new_cmap
 
 
-def to_colors(colors, fmt='rgba', length=None,
-              vmin=None, vmax=None, cmap=None):
+def to_colors(
+    colors, fmt="rgba", length=None, vmin=None, vmax=None, cmap=None, dtype=None
+):
     """
     format colors according to fmt argument
     Args:
@@ -85,6 +89,7 @@ def to_colors(colors, fmt='rgba', length=None,
         vmin (float)
         vmax (float)
         cmap (str|mpl.cm.ColorMap)
+        dtype (np.dtype): output data type
 
     Returns:
         colors in fmt
@@ -93,25 +98,25 @@ def to_colors(colors, fmt='rgba', length=None,
         >>> import rna
         >>> import numpy as np
 
-        # >>> rna.plotting.colors.to_colors(1, cmap='gray')
-        # array((1., 1., 1., 1.),
-        #       dtype=[('r', '<f8'), ('g', '<f8'), ('b', '<f8'), ('a', '<f8')])
-        # >>> rna.plotting.colors.to_colors(1, fmt='rgb', length=2, cmap='gray')
-        # array([(1., 1., 1.), (1., 1., 1.)],
-        #       dtype=[('r', '<f8'), ('g', '<f8'), ('b', '<f8')])
-        # >>> rna.plotting.colors.to_colors([1], cmap='gray', vmin=0)
-        # array([(1., 1., 1., 1.)],
-        #       dtype=[('r', '<f8'), ('g', '<f8'), ('b', '<f8'), ('a', '<f8')])
-        # >>> rna.plotting.colors.to_colors('k', cmap='gray', vmin=0, vmax=0)
-        # array((0., 0., 0., 1.),
-        #       dtype=[('r', '<f8'), ('g', '<f8'), ('b', '<f8'), ('a', '<f8')])
-        # >>> rna.plotting.colors.to_colors(
-        # ...     ['xkcd:red'], fmt='rgb', length=3, cmap='gray', vmin=0, vmax=0
-        # ... )  # doctest: +ELLIPSIS
-        # array([(0.89803922, 0., 0.), (0.898..., 0., 0.), (0.898..., 0., 0.)],
-        #       dtype=[('r', '<f8'), ('g', '<f8'), ('b', '<f8')])
-        # >>> rna.plotting.colors.to_colors(1, cmap='gray', length=2, fmt='hex')
-        # array(['#ffffff', '#ffffff'], dtype='<U7')
+        >>> rna.plotting.colors.to_colors(1, cmap='gray')
+        array((1., 1., 1., 1.),
+              dtype=[('r', '<f8'), ('g', '<f8'), ('b', '<f8'), ('a', '<f8')])
+        >>> rna.plotting.colors.to_colors(1, fmt='rgb', length=2, cmap='gray')
+        array([(1., 1., 1.), (1., 1., 1.)],
+              dtype=[('r', '<f8'), ('g', '<f8'), ('b', '<f8')])
+        >>> rna.plotting.colors.to_colors([1], cmap='gray', vmin=0)
+        array([(1., 1., 1., 1.)],
+              dtype=[('r', '<f8'), ('g', '<f8'), ('b', '<f8'), ('a', '<f8')])
+        >>> rna.plotting.colors.to_colors('k', cmap='gray', vmin=0, vmax=0)
+        array((0., 0., 0., 1.),
+              dtype=[('r', '<f8'), ('g', '<f8'), ('b', '<f8'), ('a', '<f8')])
+        >>> rna.plotting.colors.to_colors(
+        ...     ['xkcd:red'], fmt='rgb', length=3, cmap='gray', vmin=0, vmax=0
+        ... )  # doctest: +ELLIPSIS
+        array([(0.89803922, 0., 0.), (0.898..., 0., 0.), (0.898..., 0., 0.)],
+              dtype=[('r', '<f8'), ('g', '<f8'), ('b', '<f8')])
+        >>> rna.plotting.colors.to_colors(1, cmap='gray', length=2, fmt='hex')
+        array(['#ffffff', '#ffffff'], dtype='<U7')
 
         Keeps the shape
         >>> rna.plotting.colors.to_colors(np.array([[[1,1],[1,1]]]),
@@ -123,8 +128,7 @@ def to_colors(colors, fmt='rgba', length=None,
     """
     # mapping also scalars to lists
     has_iter = True
-    if not hasattr(colors, '__iter__') \
-            or isinstance(colors, (string_types, tuple)):
+    if not hasattr(colors, "__iter__") or isinstance(colors, (string_types, tuple)):
         # colors is just one element
         has_iter = False
         colors = [colors]
@@ -138,58 +142,54 @@ def to_colors(colors, fmt='rgba', length=None,
     orig_fmt = color_fmt(colors)
 
     # check cmap, vmin, vmax for norm conversions
-    if orig_fmt == 'norm' or fmt == 'norm':
-        if orig_fmt == 'norm':
+    if orig_fmt == "norm" or fmt == "norm":
+        if orig_fmt == "norm":
             if cmap is None:
                 raise TypeError("converting from norm always requires cmap")
             if vmin is None:
-                vmin = min(colors) if len(set(colors)) > 1\
-                    else min(0, min(colors))
+                vmin = min(colors) if len(set(colors)) > 1 else min(0, min(colors))
             if vmax is None:
-                vmax = max(colors) if len(set(colors)) > 1\
-                    else max(1, max(colors))
+                vmax = max(colors) if len(set(colors)) > 1 else max(1, max(colors))
+
+            # already cut initial norm values
+            colors[colors < vmin] = vmin
+            colors[colors > vmax] = vmax
         else:
             if vmin is None or vmax is None or cmap is None:
-                raise TypeError("converting to norm always requires cmap, "
-                                "vmin and vmax.")
+                raise TypeError(
+                    "converting to norm always requires cmap, " "vmin and vmax."
+                )
 
     # conversion
     if fmt == orig_fmt:
         # already correct
         pass
-    elif fmt == 'norm':
+    elif fmt == "norm":
         # route everything through rgba_to_norm
-        colors_rgba = to_colors(colors, 'rgba')
+        colors_rgba = to_colors(colors, "rgba")
         colors = rgba_to_norm(colors_rgba, cmap, vmin, vmax)
-    elif fmt == 'rgb':
-        colors_rgba = to_colors(colors, 'rgba',
-                                vmin=vmin,
-                                vmax=vmax,
-                                cmap=cmap)
-        colors = colors_rgba[['r', 'g', 'b']]
-    elif fmt == 'rgba':
-        if orig_fmt in ('str', 'hex'):
+    elif fmt == "rgb":
+        colors_rgba = to_colors(colors, "rgba", vmin=vmin, vmax=vmax, cmap=cmap)
+        colors = colors_rgba[["r", "g", "b"]]
+    elif fmt == "rgba":
+        if orig_fmt in ("str", "hex"):
             colors = [mpl.colors.to_rgba(color) for color in colors]
-        elif orig_fmt == 'rgb':
+        elif orig_fmt == "rgb":
             colors = [tuple(c) + (1,) for c in colors]
-        elif orig_fmt == 'norm':
-            colors = norm_to_rgba(colors,
-                                  vmin=vmin,
-                                  vmax=vmax,
-                                  cmap=cmap)
+        elif orig_fmt == "norm":
+            colors = norm_to_rgba(colors, vmin=vmin, vmax=vmax, cmap=cmap)
         else:
-            raise NotImplementedError("Conversion from '{orig_fmt}' to rgba"
-                                      " not implemented."
-                                      .format(**locals()))
-    elif fmt == 'hex':
-        colors_rgba = to_colors(colors, 'rgba',
-                                vmin=vmin,
-                                vmax=vmax,
-                                cmap=cmap)
+            raise NotImplementedError(
+                "Conversion from '{orig_fmt}' to rgba"
+                " not implemented.".format(**locals())
+            )
+    elif fmt == "hex":
+        colors_rgba = to_colors(colors, "rgba", vmin=vmin, vmax=vmax, cmap=cmap)
         colors = [mpl.colors.to_hex(tuple(c)) for c in colors_rgba]
     else:
-        raise NotImplementedError("Color fmt '{fmt}' not implemented."
-                                  .format(**locals()))
+        raise NotImplementedError(
+            "Color fmt '{fmt}' not implemented.".format(**locals())
+        )
 
     # set correct length
     if length is not None:
@@ -207,12 +207,15 @@ def to_colors(colors, fmt='rgba', length=None,
 
     # add fmt info to array dtype
     if fmt in FMT_DTYPES:
-        dtype = FMT_DTYPES[fmt]
-    else:
-        if hasattr(colors, 'dtype'):
+        if dtype is None:
+            dtype = FMT_DTYPES[fmt]
+        else:
+            shape.append(len(FMT_DTYPES[fmt]))
+    elif hasattr(colors, "dtype"):
+        if dtype is None:
             dtype = colors.dtype
         else:
-            dtype = None  # type(colors)
+            colors = np.array([c.tolist() for c in colors])
 
     colors = np.array(colors, dtype=dtype)
 
@@ -277,8 +280,12 @@ def rgba_to_norm(colors, cmap, vmin, vmax, max_distance=1e-6):
         min_distance = np.min(distance)
         if min_distance > max_distance:
             import warnings
-            warnings.warn("Distance in color space is large ({min_distance:.6f})"  # NOQA
-                          .format(**locals()))
+
+            warnings.warn(
+                "Distance in color space is large ({min_distance:.6f})".format(  # NOQA
+                    **locals()
+                )
+            )
         scalars.append(rnge[np.argmin(distance)])
     scalars = np.array(scalars)
     return scalars
@@ -293,15 +300,15 @@ def colormap(seq):
         LinearSegmentedColormap
     """
     seq = [(None,) * 3, 0.0] + list(seq) + [1.0, (None,) * 3]
-    cdict = {'red': [], 'green': [], 'blue': []}
+    cdict = {"red": [], "green": [], "blue": []}
     for i, item in enumerate(seq):
         if isinstance(item, float):
             r1, g1, b1 = seq[i - 1]
             r2, g2, b2 = seq[i + 1]
-            cdict['red'].append([item, r1, r2])
-            cdict['green'].append([item, g1, g2])
-            cdict['blue'].append([item, b1, b2])
-    return mpl.colors.LinearSegmentedColormap('CustomMap', cdict)
+            cdict["red"].append([item, r1, r2])
+            cdict["green"].append([item, g1, g2])
+            cdict["blue"].append([item, b1, b2])
+    return mpl.colors.LinearSegmentedColormap("CustomMap", cdict)
 
 
 def color_cycle(cmap=None, n=None):
@@ -317,14 +324,13 @@ def color_cycle(cmap=None, n=None):
     if cmap:
         if n is None:
             raise AttributeError("color_cycle with cmap requires n")
-        colors = to_colors(np.linspace(0, 1, n), cmap=cmap, vmin=0, vmax=1,
-                           fmt='hex')
+        colors = to_colors(np.linspace(0, 1, n), cmap=cmap, vmin=0, vmax=1, fmt="hex")
     else:
-        colors = list([color['color']
-                       for color in mpl.rcParams['axes.prop_cycle']])
+        colors = list([color["color"] for color in mpl.rcParams["axes.prop_cycle"]])
     return cycle(colors)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     import doctest
+
     doctest.testmod()
